==> tencentcloud-sdk-java-3.0.32-sources.jar: com/tencentcloudapi/cws/v20180312/models/CreateVulsMisinformationRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cws.v20180312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CreateVulsMisinformationRequest  extends AbstractModel{

    /**
    * 漏洞ID列表
    */
    @SerializedName("VulIds")
    @Expose
    private Integer [] VulIds;

    /**
     * 获取漏洞ID列表
     * @return VulIds 漏洞ID列表
     */
    public Integer [] getVulIds() {
        return this.VulIds;
    }

    /**
     * 设置漏洞ID列表
     * @param VulIds 漏洞ID列表
     */
    public void setVulIds(Integer [] VulIds) {
        this.VulIds = VulIds;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "VulIds.", this.VulIds);

    }
}

==> tencentcloud-sdk-java-3.1.135-sources.jar: com/tencentcloudapi/cws/v20180312/models/CreateVulsMisinformationRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cws.v20180312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CreateVulsMisinformationRequest extends AbstractModel{

    /**
    * 漏洞ID列表
    */
    @SerializedName("VulIds")
    @Expose
    private Long [] VulIds;

    /**
     * Get 漏洞ID列表 
     * @return VulIds 漏洞ID列表
     */
    public Long [] getVulIds() {
        return this.VulIds;
    }

    /**
     * Set 漏洞ID列表
     * @param VulIds 漏洞ID列表
     */
    public void setVulIds(Long [] VulIds) {
        this.VulIds = VulIds;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "VulIds.", this.VulIds);

    }
}
